@@ -2,10 +2,8 @@
 Comments extension
 ------------------
 """
-from __future__ import unicode_literals
 import os
-from six.moves.urllib.parse import urljoin
-from six import text_type
+from urllib.parse import urljoin
 
 from ..utils.base import ExtensionBase
 
@@ -53,7 +51,7 @@ class Comment(ExtensionBase):
         response = self.osc.request(
             url=urljoin(self.osc.url,
                         os.path.join(*([self.base_path, obj_type]
-                                       + [text_type(x) for x in ids]))),
+                                       + [str(x) for x in ids]))),
             method="GET",
         )
         return self.osc.get_objectified_xml(response)
@@ -81,9 +79,9 @@ class Comment(ExtensionBase):
         """
         self._validate(obj_type, ids)
         url = urljoin(self.osc.url,
-                      os.path.join(*([self.base_path, obj_type] + [text_type(x) for x in ids])))
+                      os.path.join(*([self.base_path, obj_type] + [str(x) for x in ids])))
         params = {}
-        if parent_id and text_type(parent_id).isnumeric():
+        if parent_id and str(parent_id).isnumeric():
             params["parent_id"] = parent_id
 
         response = self.osc.request(
@@ -109,7 +107,7 @@ class Comment(ExtensionBase):
         :return: ``True``, if successful. Otherwise API response
         :rtype: bool or lxml.objectify.ObjectifiedElement
         """
-        url = urljoin(self.osc.url, '/comment/' + text_type(comment_id))
+        url = urljoin(self.osc.url, '/comment/' + str(comment_id))
 
         response = self.osc.request(
             url=url,
