@@ -372,20 +372,16 @@ class TestRequest(OscTest):
             self.assertEqual(len(response.xpath("//request/history")), 5)
 
     @responses.activate
-    def test_cmd(self):
-        with self.subTest("plain diff"):
-            response = self.osc.requests.cmd(30902, "diff")
-            self.assertTrue(isinstance(response, str))
-            self.assertIn("changes files:", response)
-            self.assertIn("+++ perl-XML-DOM-XPath.changes", response)
-        with self.subTest("xml diff"):
-            response = self.osc.requests.cmd(30902, "diff", view="xml")
-            self.assertTrue(isinstance(response, ObjectifiedElement))
-        with self.subTest("changereviewstate"):
-            self.assertRaises(
-                ValueError,
-                self.osc.requests.cmd, 30902, "changereviewstate"
-            )
+    def test_update(self):
+        for method in (self.osc.requests.update, self.osc.requests.cmd):
+            with self.subTest(f"{method}, cmd=diff, plain"):
+                response = method(30902, cmd="diff")
+                self.assertTrue(isinstance(response, str))
+                self.assertIn("changes files:", response)
+                self.assertIn("+++ perl-XML-DOM-XPath.changes", response)
+            with self.subTest(f"{method}, cmd=diff, xml"):
+                response = method(30902, cmd="diff", view="xml")
+                self.assertTrue(isinstance(response, ObjectifiedElement))
 
     @responses.activate
     def test_comment(self):
